@@ -4,11 +4,11 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/acp.el
-;; Package-Version: 20251219.2135
-;; Package-Revision: 7b67facc657a
+;; Package-Version: 20260118.1815
+;; Package-Revision: 9ab9b8f25cd7
 ;; Package-Requires: ((emacs "28.1"))
 
-(defconst acp-package-version "0.8.2")
+(defconst acp-package-version "0.8.3")
 
 ;; This package is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -376,13 +376,18 @@ SYNC: When non-nil, send request synchronously."
   (unless response
     (error ":response is required"))
   (let* ((request-id (map-elt response :request-id))
-         (result-data (map-elt response :result)))
+         (result-data (map-elt response :result))
+         (error-data (map-elt response :error)))
     (map-put! client :request-id (or request-id
                                      (1+ (map-elt client :request-id))))
     (let* ((proc (map-elt client :process))
-           (response `((jsonrpc . ,acp--jsonrpc-version)
-                       (id . ,request-id)
-                       (result . ,result-data))))
+           (response (if error-data
+                         `((jsonrpc . ,acp--jsonrpc-version)
+                           (id . ,request-id)
+                           (error . ,error-data))
+                       `((jsonrpc . ,acp--jsonrpc-version)
+                         (id . ,request-id)
+                         (result . ,result-data)))))
       (let ((json (acp--serialize-json response)))
         (acp--log-traffic client 'outgoing 'response (acp--make-message :object response :json json))
         (process-send-string proc json)))))
